summaryrefslogtreecommitdiffstats
path: root/src/engine/SCons/Script
diff options
context:
space:
mode:
authorDirk Baechle <dl9obn@darc.de>2013-10-25 00:00:04 (GMT)
committerDirk Baechle <dl9obn@darc.de>2013-10-25 00:00:04 (GMT)
commit2be0f31b80087974b5e6d53e12542637636a2253 (patch)
tree0a66e71ac007288dc76949e6169218aea00e5ad0 /src/engine/SCons/Script
parentd48a4a49d3ad33311dcefa86377b005b06c285a7 (diff)
downloadSCons-2be0f31b80087974b5e6d53e12542637636a2253.zip
SCons-2be0f31b80087974b5e6d53e12542637636a2253.tar.gz
SCons-2be0f31b80087974b5e6d53e12542637636a2253.tar.bz2
- now counting instances only when requested via --debug=count
Diffstat (limited to 'src/engine/SCons/Script')
-rw-r--r--src/engine/SCons/Script/Main.py5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/engine/SCons/Script/Main.py b/src/engine/SCons/Script/Main.py
index 837c103..9083b8e 100644
--- a/src/engine/SCons/Script/Main.py
+++ b/src/engine/SCons/Script/Main.py
@@ -622,7 +622,7 @@ def _set_debug_values(options):
debug_values = options.debug
if "count" in debug_values:
# All of the object counts are within "if __debug__:" blocks,
# which get stripped when running optimized (with python -O or
# from compiled *.pyo files). Provide a warning if __debug__ is
# stripped, so it doesn't just look like --debug=count is broken.
@@ -630,6 +630,7 @@ def _set_debug_values(options):
if __debug__: enable_count = True
if enable_count:
count_stats.enable(sys.stdout)
+ SCons.Debug.track_instances = True
else:
msg = "--debug=count is not supported when running SCons\n" + \
"\twith the python -O option or optimized (.pyo) modules."
@@ -644,6 +645,8 @@ def _set_debug_values(options):
if "memory" in debug_values:
memory_stats.enable(sys.stdout)
print_objects = ("objects" in debug_values)
+ if print_objects:
+ SCons.Debug.track_instances = True
if "presub" in debug_values:
SCons.Action.print_actions_presub = 1
if "stacktrace" in debug_values:
@@ -622,7 +622,7 @@ def _set_debug_values(options):
debug_values = options.debug
if "count" in debug_values:
- # All of the object counts are within "if __debug__:" blocks,
+ # All of the object counts are within "if track_instances:" blocks,
# which get stripped when running optimized (with python -O or
# from compiled *.pyo files). Provide a warning if __debug__ is